# RapidHost

RapidHost é uma biblioteca Python para servir páginas HTML estáticas com Flask e configurações personalizáveis de IP, porta e caminho dos templates.

## Instalação

Para instalar o RapidHost, você pode usar o pip:

```bash
pip install RapidHost
    